==> haskell-aeson-casing-0.2.0.0-164-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-aeson-casing.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 aeson-casing
version:              0.2.0.0
visibility:           public
id:                   aeson-casing-0.2.0.0-2cFW7g5JAGp54Memqnyhrc
key:                  aeson-casing-0.2.0.0-2cFW7g5JAGp54Memqnyhrc
license:              MIT
maintainer:           andrewrademacher@gmail.com
author:               Andrew Rademacher
synopsis:
    Tools to change the formatting of field names in Aeson
    instances.

description:
    Tools to change the formatting of field names in Aeson
    instances. This includes CamelCasing, Pascal Casing and
    Snake Casing.

category:             Data
abi:                  92a8ded3cac505ab1068bd25dc37875e
exposed:              True
exposed-modules:      Data.Aeson.Casing Data.Aeson.Casing.Internal
import-dirs:          /usr/lib/ghc-9.4.8/site-local/aeson-casing-0.2.0.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/aeson-casing-0.2.0.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/aeson-casing-0.2.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-aeson-casing
hs-libraries:         HSaeson-casing-0.2.0.0-2cFW7g5JAGp54Memqnyhrc
depends:              aeson-2.1.2.1-I3cDhpx2rWKJLPqMhNImsD base-4.17.2.1
haddock-interfaces:
    /usr/share/doc/haskell-aeson-casing/html/aeson-casing.haddock

haddock-html:         /usr/share/doc/haskell-aeson-casing/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-aeson-casing-0.2.0.0-165-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-aeson-casing.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 aeson-casing
version:              0.2.0.0
visibility:           public
id:                   aeson-casing-0.2.0.0-HwlfhX4ZygoEW1VppWDcDr
key:                  aeson-casing-0.2.0.0-HwlfhX4ZygoEW1VppWDcDr
license:              MIT
maintainer:           andrewrademacher@gmail.com
author:               Andrew Rademacher
synopsis:
    Tools to change the formatting of field names in Aeson
    instances.

description:
    Tools to change the formatting of field names in Aeson
    instances. This includes CamelCasing, Pascal Casing and
    Snake Casing.

category:             Data
abi:                  2e98cc5e411ff3af5e14bd76ab1771f3
exposed:              True
exposed-modules:      Data.Aeson.Casing Data.Aeson.Casing.Internal
import-dirs:          /usr/lib/ghc-9.4.8/site-local/aeson-casing-0.2.0.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/aeson-casing-0.2.0.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/aeson-casing-0.2.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-aeson-casing
hs-libraries:         HSaeson-casing-0.2.0.0-HwlfhX4ZygoEW1VppWDcDr
depends:              aeson-2.1.2.1-5gViDrHjeNhDfT19MwgeMT base-4.17.2.1
haddock-interfaces:
    /usr/share/doc/haskell-aeson-casing/html/aeson-casing.haddock

haddock-html:         /usr/share/doc/haskell-aeson-casing/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
